Documentation
¶
Index ¶
- Constants
- func AlreadyExistsError(format string, a ...interface{}) *ierror.Error
- func CombineErrors(errs ...error) error
- func ConfigError(format string, a ...interface{}) *ierror.Error
- func ConflictedError(format string, a ...interface{}) *ierror.Error
- func ConnectionError(format string, a ...interface{}) *ierror.Error
- func ConstraintViolatedError(format string, a ...interface{}) *ierror.Error
- func CryptoOperationError(format string, a ...interface{}) *ierror.Error
- func DataCorruptedError(format string, a ...interface{}) *ierror.Error
- func DataError(format string, a ...interface{}) *ierror.Error
- func DependencyFailureError(format string, a ...interface{}) *ierror.Error
- func EncodingError(format string, a ...interface{}) *ierror.Error
- func Errorf(code uint64, format string, a ...interface{}) *ierror.Error
- func EthConnectionError(format string, a ...interface{}) *ierror.Error
- func EthereumError(format string, a ...interface{}) *ierror.Error
- func FaucetWarning(format string, a ...interface{}) *ierror.Error
- func FeatureNotSupportedError(format string, a ...interface{}) *ierror.Error
- func FromError(err error) *ierror.Error
- func HTTPConnectionError(format string, a ...interface{}) *ierror.Error
- func InternalError(format string, a ...interface{}) *ierror.Error
- func InvalidArgError(format string, a ...interface{}) *ierror.Error
- func InvalidArgsCountError(format string, a ...interface{}) *ierror.Error
- func InvalidAuthenticationError(format string, a ...interface{}) *ierror.Error
- func InvalidCryptographicSignatureError(format string, a ...interface{}) *ierror.Error
- func InvalidEventDataError(format string, a ...interface{}) *ierror.Error
- func InvalidFormatError(format string, a ...interface{}) *ierror.Error
- func InvalidNonceError(format string, a ...interface{}) *ierror.Error
- func InvalidNonceWarning(format string, a ...interface{}) *ierror.Error
- func InvalidParameterError(format string, a ...interface{}) *ierror.Error
- func InvalidSignatureError(format string, a ...interface{}) *ierror.Error
- func InvalidStateError(format string, a ...interface{}) *ierror.Error
- func InvalidTopicsCountError(format string, a ...interface{}) *ierror.Error
- func IsAlreadyExistsError(err error) bool
- func IsConflictedError(err error) bool
- func IsConnectionError(err error) bool
- func IsConstraintViolatedError(err error) bool
- func IsCryptoOperationError(err error) bool
- func IsDataCorruptedError(err error) bool
- func IsDataError(err error) bool
- func IsDependencyFailureError(err error) bool
- func IsEncodingError(err error) bool
- func IsEthConnectionError(err error) bool
- func IsEthereumError(err error) bool
- func IsFaucetWarning(err error) bool
- func IsFeatureNotSupportedError(err error) bool
- func IsInternalError(err error) bool
- func IsInvalidArgError(err error) bool
- func IsInvalidAuthenticationError(err error) bool
- func IsInvalidCryptographicSignatureError(err error) bool
- func IsInvalidFormatError(err error) bool
- func IsInvalidNonceWarning(err error) bool
- func IsInvalidParameterError(err error) bool
- func IsInvalidStateError(err error) bool
- func IsKafkaConnectionError(err error) bool
- func IsNotFoundError(err error) bool
- func IsPostgresConnectionError(err error) bool
- func IsServiceConnectionError(err error) bool
- func IsSolidityError(err error) bool
- func IsStorageError(err error) bool
- func IsUnauthorizedError(err error) bool
- func IsWarning(err error) bool
- func KafkaConnectionError(format string, a ...interface{}) *ierror.Error
- func NonceTooHighWarning(format string, a ...interface{}) *ierror.Error
- func NonceTooLowError(format string, a ...interface{}) *ierror.Error
- func NonceTooLowWarning(format string, a ...interface{}) *ierror.Error
- func NotFoundError(format string, a ...interface{}) *ierror.Error
- func PermissionDeniedError(format string, a ...interface{}) *ierror.Error
- func PostgresConnectionError(format string, a ...interface{}) *ierror.Error
- func RedisConnectionError(format string, a ...interface{}) *ierror.Error
- func ServiceConnectionError(format string, a ...interface{}) *ierror.Error
- func SolidityError(format string, a ...interface{}) *ierror.Error
- func StorageError(format string, a ...interface{}) *ierror.Error
- func UnauthorizedError(format string, a ...interface{}) *ierror.Error
- func Warningf(format string, a ...interface{}) *ierror.Error
Constants ¶
const ( // Warnings (class 01XXX) Warning uint64 = 1 << 12 // Faucet (class 012XX) Faucet = Warning + 2<<8 // Faucet credit denied // Invalid Nonce warnings(class 013xx) InvalidNonce = Warning + 3<<8 InvalidNonceTooHigh = InvalidNonce + 1 InvalidNonceTooLow = InvalidNonce + 2 // Connection Errors (class 08XXX) Connection uint64 = 8 << 12 KafkaConnection = Connection + 1<<8 // Kafka Connection error (subclass 081XX) HTTPConnection = Connection + 2<<8 // HTTP Connection error (subclass 082XX) EthConnection = Connection + 3<<8 // Ethereum Connection error (subclass 083XX) RedisConnection = Connection + 5<<8 // Redis Connection error (subclass 085XX) PostgresConnection = Connection + 6<<8 // Postgres Connection error (subclass 086XX) ServiceConnection = Connection + 7<<8 // Service Connection error (subclass 087XX) // Authentication Errors (class 09XXX) InvalidAuthentication uint64 = 9 << 12 PermissionDenied = InvalidAuthentication + 2 // no permission to execute operation (code 09002) // Feature Not Supported Errors (class 0AXXX) FeatureNotSupported uint64 = 10 << 12 // Invalid State (class 24XXX) InvalidState uint64 = 2<<16 + 4<<12 Conflicted = InvalidState + 2<<8 // Conflict with current system state (subclass 242XX) // Message Errors (class 42XXX) Data uint64 = 4<<16 + 2<<12 Encoding = Data + 1<<8 // Invalid Encoding (subclass 421XX) Solidity = Data + 2<<8 // Solidity Errors (subclass 422XX) InvalidSignature = Solidity + 1 // Invalid method/event signature (code 42201) InvalidArgsCount = Solidity + 2 // Invalid arguments count (code 42202) InvalidArg = Solidity + 3 // Invalid argument format (code 42203) InvalidTopicsCount = Solidity + 4 // Invalid count of topics in receipt (code 42204) InvalidLog = Solidity + 5 // Invalid event log (code 42205) InvalidFormat = Data + 3<<8 // Invalid format (subclass 423XX) InvalidParameter = Data + 4<<8 // Invalid parameter provided (subclass 424XX) // Ethereum error (class BEXXX) Ethereum uint64 = 11<<16 + 14<<12 NonceTooLow = Ethereum + 1 InvalidNonceErr = Ethereum + 2 // Cryptographic operation error (class C0XXX) CryptoOperation uint64 = 12 << 16 InvalidCryptographicSignature = CryptoOperation + 1 // Invalid signature during cryptographic verification (subclass C0001) // Storage Error (class DBXXX) Storage uint64 = 13<<16 + 11<<12 ConstraintViolated = Storage + 1<<8 // Storage constraint violated (subclass DB1XX) AlreadyExists = ConstraintViolated + 1 // A resource with same index already exists (code DB101) NotFound = Storage + 2<<8 // Not found (subclass DB2XX) // Configuration errors (class F0XXX) Config uint64 = 15 << 16 // Internal errors (class FFXXX) Internal uint64 = 15<<16 + 15<<12 DataCorrupted = Internal + 1<<8 // Message corrupted (subclass FF1XX) DependencyFailure = Internal + 2<<8 // Message corrupted (subclass FF2XX) )
Error codes are uint64 for performances purposes but should be seen as 5 nibbles hex codes
Variables ¶
This section is empty.
Functions ¶
func AlreadyExistsError ¶
AlreadyExistsError is raised when a Message constraint has been violated
func CombineErrors ¶
func ConfigError ¶
ConfigError is raised when an error is encountered while loading configuration
func ConflictedError ¶
ConflictedError is raised when operation could not be completed due to a conflict with the current state of the target resource
User might be able to resolve the conflict and resubmit operation
func ConnectionError ¶
ConnectionError is raised when failing to connect to an external service
func ConstraintViolatedError ¶
ConstraintViolatedError is raised when a Message constraint has been violated
func CryptoOperationError ¶
CryptoOperationError is raised when failing a cryptographic operation
func DataCorruptedError ¶
DataCorruptedError is raised loading a corrupted Message
func DependencyFailureError ¶
func EncodingError ¶
EncodingError are raised when failing to decode a message
func EthConnectionError ¶
EthConnectionError is raised when failing to connect to Ethereum client jsonRPC API
func EthereumError ¶
EthereumError is raised when JSON-RPC call returns an error (such as Nonce too Low)
func FaucetWarning ¶
FaucetWarning are raised when a faucet credit has been denied
func FeatureNotSupportedError ¶
FeatureNotSupportedError is raised when using a feature which is not implemented
func FromError ¶
FromError cast a golang error into an internal Error
if `err` is an internal then it is returned
func HTTPConnectionError ¶
HTTPConnectionError is raised when failing to connect over http
func InternalError ¶
InternalError is raised when an unknown exception is met
func InvalidArgError ¶
InvalidArgError is raised when invalid argument is provided to craft a transaction
func InvalidArgsCountError ¶
InvalidArgsCountError is raised when invalid arguments count is provided to craft a transaction
func InvalidAuthenticationError ¶
InvalidAuthenticationError is raised when access to an operation has been denied
func InvalidCryptographicSignatureError ¶
InvalidCryptographicSignature is raised when failing a signature cryptographic verification
func InvalidEventDataError ¶
InvalidEventDataError is raised when event Message is invalid
func InvalidFormatError ¶
InvalidFormatError is raised when a Message does not match an expected format
func InvalidNonceError ¶
NonceTooLowWarning are raised when about to send a transaction with nonce too low
func InvalidNonceWarning ¶
InvalidNonceWarning are raised when an invalid nonce is detected
func InvalidParameterError ¶
InvalidParameterError is raised when a provided parameter invalid
func InvalidSignatureError ¶
InvalidSignatureError is raised when a Solidity method signature is invalid
func InvalidStateError ¶
InvalidStateError is raised when system state blocks operation execution
func InvalidTopicsCountError ¶
InvalidTopicsCountError is raised when topics count is in receipt
func IsAlreadyExistsError ¶
IsAlreadyExistsError indicate whether an error is an already exists error
func IsConflictedError ¶
IsConflictedError indicate whether an error is an conflicted error
func IsConnectionError ¶
IsConnectionError indicate whether an error is a Connection error
func IsConstraintViolatedError ¶
IsConstraintViolatedError indicate whether an error is a constraint violated error
func IsCryptoOperationError ¶
IsCryptoOperationError indicate whether an error is a cryptographic operation error
func IsDataCorruptedError ¶
IsDataCorruptedError indicate whether an error is a data corrupted error
func IsDataError ¶
IsDataError indicate whether an error is a Message error
func IsEncodingError ¶
IsEncodingError indicate whether an error is a EncodingError error
func IsEthConnectionError ¶
IsEthConnectionError indicate whether an error is a EthConnection error
func IsEthereumError ¶
IsEthereumError indicate whether an error is an Ethereum error
func IsFaucetWarning ¶
IsFaucetWarning indicate whether an error is a faucet Warning
func IsFeatureNotSupportedError ¶
IsFeatureNotSupportedError indicate whether an error is a feature not supported error
func IsInternalError ¶
IsInternalError indicate whether an error is an Internal error
func IsInvalidArgError ¶
func IsInvalidAuthenticationError ¶
AuthenticationError indicate whether an error is an authentication error
func IsInvalidCryptographicSignatureError ¶
IsInvalidCryptographicSignatureError indicate whether an error is a signature cryptographic verification error
func IsInvalidFormatError ¶
IsInvalidFormatError indicate whether an error is an invalid format error
func IsInvalidNonceWarning ¶
IsInvalidNonceWarning indicate whether an error is an invalid nonce Warning
func IsInvalidParameterError ¶
IsInvalidParameterError indicate whether an error is an invalid parameter error
func IsInvalidStateError ¶
AuthenticationError indicate whether an error is an invalid state error
func IsKafkaConnectionError ¶
IsKafkaConnectionError indicate whether an error is a KafkaConnection error
func IsNotFoundError ¶
IsNotFoundError indicate whether an error is a no Message found error
func IsPostgresConnectionError ¶
IsPostgresConnectionError indicate whether an error is a Postgres connection error
func IsServiceConnectionError ¶
IsServiceConnectionError indicate whether an error is a Service connection error
func IsSolidityError ¶
IsSolidityError indicate whether an error is a Solidity error
func IsStorageError ¶
IsStorageError indicate whether an error is a Storage error
func IsUnauthorizedError ¶
func KafkaConnectionError ¶
KafkaConnectionError is raised when failing to connect to Kafka
func NonceTooHighWarning ¶
NonceTooHighWarning are raised when about to send a transaction with nonce too high
func NonceTooLowError ¶
NonceTooLowError is raised when JSON-RPC returns a "Nonce too low" when sending a transaction
func NonceTooLowWarning ¶
NonceTooLowWarning are raised when about to send a transaction with nonce too low
func NotFoundError ¶
NoDataFoundError is raised when accessing a missing Message
func PermissionDeniedError ¶
PermissionDeniedError is raised when authentication credentials are invalid
func PostgresConnectionError ¶
PostgresConnectionError is raised when failing to connect to Postgres
func RedisConnectionError ¶
RedisConnectionError is raised when failing to connect to Redis
func ServiceConnectionError ¶
ServiceConnectionError is raised when failing to connect to another service
func SolidityError ¶
SolidityError is raised when a Message related in transaction crafting is incorrect
func StorageError ¶
StorageError is raised when an error is encountered while accessing stored Message
func UnauthorizedError ¶
UnauthorizedError is raised when authentication credentials are invalid
Types ¶
This section is empty.